@@ -3,11 +3,15 @@ from __future__ import unicode_literals
 import importlib
 
 
-def lazy_load(module_name, element):
+def lazy_load(module_name, element, boto3_name=None, backend=None):
     def f(*args, **kwargs):
         module = importlib.import_module(module_name, "moto")
         return getattr(module, element)(*args, **kwargs)
 
+    setattr(f, "name", module_name.replace(".", ""))
+    setattr(f, "element", element)
+    setattr(f, "boto3_name", boto3_name or f.name)
+    setattr(f, "backend", backend or f"{f.name}_backends")
     return f
 
 
@@ -20,7 +24,9 @@ mock_applicationautoscaling = lazy_load(
 )
 mock_autoscaling = lazy_load(".autoscaling", "mock_autoscaling")
 mock_autoscaling_deprecated = lazy_load(".autoscaling", "mock_autoscaling_deprecated")
-mock_lambda = lazy_load(".awslambda", "mock_lambda")
+mock_lambda = lazy_load(
+    ".awslambda", "mock_lambda", boto3_name="lambda", backend="lambda_backends"
+)
 mock_lambda_deprecated = lazy_load(".awslambda", "mock_lambda_deprecated")
 mock_batch = lazy_load(".batch", "mock_batch")
 mock_batch = lazy_load(".batch", "mock_batch")
@@ -32,11 +38,13 @@ mock_cloudwatch = lazy_load(".cloudwatch", "mock_cloudwatch")
 mock_cloudwatch_deprecated = lazy_load(".cloudwatch", "mock_cloudwatch_deprecated")
 mock_codecommit = lazy_load(".codecommit", "mock_codecommit")
 mock_codepipeline = lazy_load(".codepipeline", "mock_codepipeline")
-mock_cognitoidentity = lazy_load(".cognitoidentity", "mock_cognitoidentity")
+mock_cognitoidentity = lazy_load(
+    ".cognitoidentity", "mock_cognitoidentity", boto3_name="cognito-identity"
+)
 mock_cognitoidentity_deprecated = lazy_load(
     ".cognitoidentity", "mock_cognitoidentity_deprecated"
 )
-mock_cognitoidp = lazy_load(".cognitoidp", "mock_cognitoidp")
+mock_cognitoidp = lazy_load(".cognitoidp", "mock_cognitoidp", boto3_name="cognito-idp")
 mock_cognitoidp_deprecated = lazy_load(".cognitoidp", "mock_cognitoidp_deprecated")
 mock_config = lazy_load(".config", "mock_config")
 mock_datapipeline = lazy_load(".datapipeline", "mock_datapipeline")
@@ -47,10 +55,12 @@ mock_datasync = lazy_load(".datasync", "mock_datasync")
 mock_dms = lazy_load(".dms", "mock_dms")
 mock_dynamodb = lazy_load(".dynamodb", "mock_dynamodb")
 mock_dynamodb_deprecated = lazy_load(".dynamodb", "mock_dynamodb_deprecated")
-mock_dynamodb2 = lazy_load(".dynamodb2", "mock_dynamodb2")
+mock_dynamodb2 = lazy_load(".dynamodb2", "mock_dynamodb2", backend="dynamodb_backends2")
 mock_dynamodb2_deprecated = lazy_load(".dynamodb2", "mock_dynamodb2_deprecated")
 mock_dynamodbstreams = lazy_load(".dynamodbstreams", "mock_dynamodbstreams")
-mock_elasticbeanstalk = lazy_load(".elasticbeanstalk", "mock_elasticbeanstalk")
+mock_elasticbeanstalk = lazy_load(
+    ".elasticbeanstalk", "mock_elasticbeanstalk", backend="eb_backends"
+)
 mock_ec2 = lazy_load(".ec2", "mock_ec2")
 mock_ec2_deprecated = lazy_load(".ec2", "mock_ec2_deprecated")
 mock_ec2instanceconnect = lazy_load(".ec2instanceconnect", "mock_ec2instanceconnect")
@@ -65,6 +75,7 @@ mock_elbv2 = lazy_load(".elbv2", "mock_elbv2")
 mock_emr = lazy_load(".emr", "mock_emr")
 mock_emr_deprecated = lazy_load(".emr", "mock_emr_deprecated")
 mock_events = lazy_load(".events", "mock_events")
+mock_firehose = lazy_load(".firehose", "mock_firehose")
 mock_forecast = lazy_load(".forecast", "mock_forecast")
 mock_glacier = lazy_load(".glacier", "mock_glacier")
 mock_glacier_deprecated = lazy_load(".glacier", "mock_glacier_deprecated")
@@ -72,7 +83,7 @@ mock_glue = lazy_load(".glue", "mock_glue")
 mock_iam = lazy_load(".iam", "mock_iam")
 mock_iam_deprecated = lazy_load(".iam", "mock_iam_deprecated")
 mock_iot = lazy_load(".iot", "mock_iot")
-mock_iotdata = lazy_load(".iotdata", "mock_iotdata")
+mock_iotdata = lazy_load(".iotdata", "mock_iotdata", boto3_name="iot-data")
 mock_kinesis = lazy_load(".kinesis", "mock_kinesis")
 mock_kinesis_deprecated = lazy_load(".kinesis", "mock_kinesis_deprecated")
 mock_kms = lazy_load(".kms", "mock_kms")
@@ -87,11 +98,13 @@ mock_polly = lazy_load(".polly", "mock_polly")
 mock_ram = lazy_load(".ram", "mock_ram")
 mock_rds = lazy_load(".rds", "mock_rds")
 mock_rds_deprecated = lazy_load(".rds", "mock_rds_deprecated")
-mock_rds2 = lazy_load(".rds2", "mock_rds2")
+mock_rds2 = lazy_load(".rds2", "mock_rds2", boto3_name="rds")
 mock_rds2_deprecated = lazy_load(".rds2", "mock_rds2_deprecated")
 mock_redshift = lazy_load(".redshift", "mock_redshift")
 mock_redshift_deprecated = lazy_load(".redshift", "mock_redshift_deprecated")
-mock_resourcegroups = lazy_load(".resourcegroups", "mock_resourcegroups")
+mock_resourcegroups = lazy_load(
+    ".resourcegroups", "mock_resourcegroups", boto3_name="resource-groups"
+)
 mock_resourcegroupstaggingapi = lazy_load(
     ".resourcegroupstaggingapi", "mock_resourcegroupstaggingapi"
 )
@@ -108,7 +121,9 @@ mock_sns_deprecated = lazy_load(".sns", "mock_sns_deprecated")
 mock_sqs = lazy_load(".sqs", "mock_sqs")
 mock_sqs_deprecated = lazy_load(".sqs", "mock_sqs_deprecated")
 mock_ssm = lazy_load(".ssm", "mock_ssm")
-mock_stepfunctions = lazy_load(".stepfunctions", "mock_stepfunctions")
+mock_stepfunctions = lazy_load(
+    ".stepfunctions", "mock_stepfunctions", backend="stepfunction_backends"
+)
 mock_sts = lazy_load(".sts", "mock_sts")
 mock_sts_deprecated = lazy_load(".sts", "mock_sts_deprecated")
 mock_swf = lazy_load(".swf", "mock_swf")
@@ -119,7 +134,9 @@ mock_xray = lazy_load(".xray", "mock_xray")
 mock_xray_client = lazy_load(".xray", "mock_xray_client")
 mock_kinesisvideo = lazy_load(".kinesisvideo", "mock_kinesisvideo")
 mock_kinesisvideoarchivedmedia = lazy_load(
-    ".kinesisvideoarchivedmedia", "mock_kinesisvideoarchivedmedia"
+    ".kinesisvideoarchivedmedia",
+    "mock_kinesisvideoarchivedmedia",
+    boto3_name="kinesis-video-archived-media",
 )
 mock_medialive = lazy_load(".medialive", "mock_medialive")
 mock_support = lazy_load(".support", "mock_support")
@@ -127,7 +144,9 @@ mock_mediaconnect = lazy_load(".mediaconnect", "mock_mediaconnect")
 mock_mediapackage = lazy_load(".mediapackage", "mock_mediapackage")
 mock_mediastore = lazy_load(".mediastore", "mock_mediastore")
 mock_eks = lazy_load(".eks", "mock_eks")
-mock_mediastoredata = lazy_load(".mediastoredata", "mock_mediastoredata")
+mock_mediastoredata = lazy_load(
+    ".mediastoredata", "mock_mediastoredata", boto3_name="mediastore-data"
+)
 mock_efs = lazy_load(".efs", "mock_efs")
 mock_wafv2 = lazy_load(".wafv2", "mock_wafv2")
 
@@ -135,7 +154,7 @@ mock_wafv2 = lazy_load(".wafv2", "mock_wafv2")
 # logging.getLogger('boto').setLevel(logging.CRITICAL)
 
 __title__ = "moto"
-__version__ = "2.2.6"
+__version__ = "2.2.7"
 
 
 try:
