@@ -35,11 +35,32 @@ class InstanceState(object):
         lifecycle_state="InService",
         health_status="Healthy",
         protected_from_scale_in=False,
+        autoscaling_group=None,
     ):
         self.instance = instance
         self.lifecycle_state = lifecycle_state
         self.health_status = health_status
         self.protected_from_scale_in = protected_from_scale_in
+        if not hasattr(self.instance, "autoscaling_group"):
+            self.instance.autoscaling_group = autoscaling_group
+
+
+class FakeLifeCycleHook(BaseModel):
+    def __init__(
+        self, name, as_name, transition, timeout, result,
+    ):
+        self.name = name
+        self.as_name = as_name
+        if transition:
+            self.transition = transition
+        if timeout:
+            self.timeout = timeout
+        else:
+            self.timeout = 3600
+        if result:
+            self.result = result
+        else:
+            self.result = "ABANDON"
 
 
 class FakeScalingPolicy(BaseModel):
@@ -589,6 +610,7 @@ class AutoScalingBackend(BaseBackend):
         self.autoscaling_groups = OrderedDict()
         self.launch_configurations = OrderedDict()
         self.policies = {}
+        self.lifecycle_hooks = {}
         self.ec2_backend = ec2_backend
         self.elb_backend = elb_backend
         self.elbv2_backend = elbv2_backend
@@ -821,6 +843,7 @@ class AutoScalingBackend(BaseBackend):
                 InstanceState(
                     self.ec2_backend.get_instance(x),
                     protected_from_scale_in=group.new_instances_protected_from_scale_in,
+                    autoscaling_group=group,
                 )
                 for x in instance_ids
             ]
@@ -893,6 +916,25 @@ class AutoScalingBackend(BaseBackend):
             desired_capacity = int(desired_capacity)
         self.set_desired_capacity(group_name, desired_capacity)
 
+    def create_lifecycle_hook(self, name, as_name, transition, timeout, result):
+        lifecycle_hook = FakeLifeCycleHook(name, as_name, transition, timeout, result,)
+
+        self.lifecycle_hooks["%s_%s" % (as_name, name)] = lifecycle_hook
+        return lifecycle_hook
+
+    def describe_lifecycle_hooks(self, as_name, lifecycle_hook_names=None):
+        return [
+            lifecycle_hook
+            for lifecycle_hook in self.lifecycle_hooks.values()
+            if (lifecycle_hook.as_name == as_name)
+            and (
+                not lifecycle_hook_names or lifecycle_hook.name in lifecycle_hook_names
+            )
+        ]
+
+    def delete_lifecycle_hook(self, as_name, name):
+        self.lifecycle_hooks.pop("%s_%s" % (as_name, name), None)
+
     def create_autoscaling_policy(
         self, name, policy_type, adjustment_type, as_name, scaling_adjustment, cooldown
     ):
