@@ -1,5 +1,4 @@
 from __future__ import unicode_literals
-import six
 import random
 import string
 import hashlib
@@ -10,7 +9,7 @@ import base64
 def create_id():
     size = 26
     chars = list(range(10)) + list(string.ascii_lowercase)
-    return "".join(six.text_type(random.choice(chars)) for x in range(size))
+    return "".join(str(random.choice(chars)) for x in range(size))
 
 
 def check_secret_hash(app_client_secret, app_client_id, username, secret_hash):
