@@ -124,11 +124,19 @@ class InvalidNetworkAclIdError(EC2ClientError):
 
 
 class InvalidVpnGatewayIdError(EC2ClientError):
-    def __init__(self, network_acl_id):
+    def __init__(self, vpn_gw):
         super(InvalidVpnGatewayIdError, self).__init__(
             "InvalidVpnGatewayID.NotFound",
-            "The virtual private gateway ID '{0}' does not exist".format(
-                network_acl_id
+            "The virtual private gateway ID '{0}' does not exist".format(vpn_gw),
+        )
+
+
+class InvalidVpnGatewayAttachmentError(EC2ClientError):
+    def __init__(self, vpn_gw, vpc_id):
+        super(InvalidVpnGatewayAttachmentError, self).__init__(
+            "InvalidVpnGatewayAttachment.NotFound",
+            "The attachment with vpn gateway ID '{}' and vpc ID '{}' does not exist".format(
+                vpn_gw, vpc_id
             ),
         )
 
@@ -677,3 +685,29 @@ class InvalidTaggableResourceType(EC2ClientError):
                 resource_type
             ),
         )
+
+
+class GenericInvalidParameterValueError(EC2ClientError):
+    def __init__(self, attribute, value):
+        super(GenericInvalidParameterValueError, self).__init__(
+            "InvalidParameterValue",
+            "invalid value for parameter {0}: {1}".format(attribute, value),
+        )
+
+
+class InvalidSubnetCidrBlockAssociationID(EC2ClientError):
+    def __init__(self, association_id):
+        super(InvalidSubnetCidrBlockAssociationID, self).__init__(
+            "InvalidSubnetCidrBlockAssociationID.NotFound",
+            "The subnet CIDR block with association ID '{0}' does not exist".format(
+                association_id
+            ),
+        )
+
+
+class InvalidCarrierGatewayID(EC2ClientError):
+    def __init__(self, carrier_gateway_id):
+        super(InvalidCarrierGatewayID, self).__init__(
+            "InvalidCarrierGatewayID.NotFound",
+            "The CarrierGateway ID '{0}' does not exist".format(carrier_gateway_id),
+        )
