@@ -18,6 +18,7 @@ class RouteTables(BaseResponse):
         route_table_id = self._get_param("RouteTableId")
         destination_cidr_block = self._get_param("DestinationCidrBlock")
         destination_ipv6_cidr_block = self._get_param("DestinationIpv6CidrBlock")
+        destination_prefix_list_id = self._get_param("DestinationPrefixListId")
         gateway_id = self._get_param("GatewayId")
         instance_id = self._get_param("InstanceId")
         nat_gateway_id = self._get_param("NatGatewayId")
@@ -25,11 +26,13 @@ class RouteTables(BaseResponse):
         transit_gateway_id = self._get_param("TransitGatewayId")
         interface_id = self._get_param("NetworkInterfaceId")
         pcx_id = self._get_param("VpcPeeringConnectionId")
+        carrier_gateway_id = self._get_param("CarrierGatewayId")
 
         self.ec2_backend.create_route(
             route_table_id,
             destination_cidr_block,
             destination_ipv6_cidr_block,
+            destination_prefix_list_id,
             gateway_id=gateway_id,
             instance_id=instance_id,
             nat_gateway_id=nat_gateway_id,
@@ -37,6 +40,7 @@ class RouteTables(BaseResponse):
             transit_gateway_id=transit_gateway_id,
             interface_id=interface_id,
             vpc_peering_connection_id=pcx_id,
+            carrier_gateway_id=carrier_gateway_id,
         )
 
         template = self.response_template(CREATE_ROUTE_RESPONSE)
@@ -83,14 +87,24 @@ class RouteTables(BaseResponse):
     def replace_route(self):
         route_table_id = self._get_param("RouteTableId")
         destination_cidr_block = self._get_param("DestinationCidrBlock")
+        destination_ipv6_cidr_block = self._get_param("DestinationIpv6CidrBlock")
+        destination_prefix_list_id = self._get_param("DestinationPrefixListId")
         gateway_id = self._get_param("GatewayId")
         instance_id = self._get_param("InstanceId")
         interface_id = self._get_param("NetworkInterfaceId")
         pcx_id = self._get_param("VpcPeeringConnectionId")
+        nat_gateway_id = self._get_param("NatGatewayId")
+        egress_only_igw_id = self._get_param("EgressOnlyInternetGatewayId")
+        transit_gateway_id = self._get_param("TransitGatewayId")
 
         self.ec2_backend.replace_route(
             route_table_id,
             destination_cidr_block,
+            destination_ipv6_cidr_block,
+            destination_prefix_list_id,
+            nat_gateway_id,
+            egress_only_igw_id,
+            transit_gateway_id,
             gateway_id=gateway_id,
             instance_id=instance_id,
             interface_id=interface_id,
@@ -176,13 +190,18 @@ DESCRIBE_ROUTE_TABLES_RESPONSE = """
                 {% if route.destination_ipv6_cidr_block %}
                 <destinationIpv6CidrBlock>{{ route.destination_ipv6_cidr_block }}</destinationIpv6CidrBlock>
                 {% else %}
-                <destinationCidrBlock>{{ route.destination_cidr_block }}</destinationCidrBlock>
+                <destinationCidrBlock>{{ route.destination_cidr_block or "" }}</destinationCidrBlock>
                 {% endif %}
                 {% if route.local %}
                   <gatewayId>local</gatewayId>
                   <origin>CreateRouteTable</origin>
                   <state>active</state>
                 {% endif %}
+                {% if route.prefix_list %}
+                  <destinationPrefixListId>{{ route.prefix_list.id }}</destinationPrefixListId>
+                  <origin>CreateRoute</origin>
+                  <state>active</state>
+                {% endif %}
                 {% if route.gateway %}
                   <gatewayId>{{ route.gateway.id }}</gatewayId>
                   <origin>CreateRoute</origin>
@@ -198,6 +217,11 @@ DESCRIBE_ROUTE_TABLES_RESPONSE = """
                   <origin>CreateRoute</origin>
                   <state>blackhole</state>
                 {% endif %}
+                {% if route.carrier_gateway %}
+                  <carrierGatewayId>{{ route.carrier_gateway.id }}</carrierGatewayId>
+                  <origin>CreateRoute</origin>
+                  <state>blackhole</state>
+                {% endif %}
                 {% if route.nat_gateway %}
                   <natGatewayId>{{ route.nat_gateway.id }}</natGatewayId>
                   <state>active</state>
@@ -210,6 +234,10 @@ DESCRIBE_ROUTE_TABLES_RESPONSE = """
                   <transitGatewayId>{{ route.transit_gateway.id }}</transitGatewayId>
                   <state>active</state>
                 {% endif %}
+                {% if route.interface %}
+                  <networkInterfaceId>{{ route.interface.id }}</networkInterfaceId>
+                  <state>active</state>
+                {% endif %}
               </item>
             {% endfor %}
           </routeSet>
