@@ -1,4 +1,5 @@
 import json
+import re
 
 from .exceptions import InvalidParameterException
 
@@ -8,6 +9,26 @@ from .models import logs_backends
 # See http://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/Welcome.html
 
 
+def validate_param(
+    param_name, param_value, constraint, constraint_expression, pattern=None
+):
+    try:
+        assert constraint_expression(param_value)
+    except (AssertionError, TypeError):
+        raise InvalidParameterException(
+            constraint=constraint, parameter=param_name, value=param_value,
+        )
+    if pattern and param_value:
+        try:
+            assert re.match(pattern, param_value)
+        except (AssertionError, TypeError):
+            raise InvalidParameterException(
+                constraint=f"Must match pattern: {pattern}",
+                parameter=param_name,
+                value=param_value,
+            )
+
+
 class LogsResponse(BaseResponse):
     @property
     def logs_backend(self):
@@ -23,6 +44,107 @@ class LogsResponse(BaseResponse):
     def _get_param(self, param, if_none=None):
         return self.request_params.get(param, if_none)
 
+    def _get_validated_param(
+        self, param, constraint, constraint_expression, pattern=None
+    ):
+        param_value = self._get_param(param)
+        validate_param(param, param_value, constraint, constraint_expression, pattern)
+        return param_value
+
+    def put_metric_filter(self):
+        filter_name = self._get_validated_param(
+            "filterName",
+            "Minimum length of 1. Maximum length of 512.",
+            lambda x: 1 <= len(x) <= 512,
+            pattern="[^:*]*",
+        )
+        filter_pattern = self._get_validated_param(
+            "filterPattern",
+            "Minimum length of 0. Maximum length of 1024.",
+            lambda x: 0 <= len(x) <= 1024,
+        )
+        log_group_name = self._get_validated_param(
+            "logGroupName",
+            "Minimum length of 1. Maximum length of 512.",
+            lambda x: 1 <= len(x) <= 512,
+            pattern="[.-_/#A-Za-z0-9]+",
+        )
+        metric_transformations = self._get_validated_param(
+            "metricTransformations", "Fixed number of 1 item.", lambda x: len(x) == 1
+        )
+
+        self.logs_backend.put_metric_filter(
+            filter_name, filter_pattern, log_group_name, metric_transformations
+        )
+
+        return ""
+
+    def describe_metric_filters(self):
+        filter_name_prefix = self._get_validated_param(
+            "filterNamePrefix",
+            "Minimum length of 1. Maximum length of 512.",
+            lambda x: x is None or 1 <= len(x) <= 512,
+            pattern="[^:*]*",
+        )
+        log_group_name = self._get_validated_param(
+            "logGroupName",
+            "Minimum length of 1. Maximum length of 512",
+            lambda x: x is None or 1 <= len(x) <= 512,
+            pattern="[.-_/#A-Za-z0-9]+",
+        )
+        metric_name = self._get_validated_param(
+            "metricName",
+            "Maximum length of 255.",
+            lambda x: x is None or len(x) <= 255,
+            pattern="[^:*$]*",
+        )
+        metric_namespace = self._get_validated_param(
+            "metricNamespace",
+            "Maximum length of 255.",
+            lambda x: x is None or len(x) <= 255,
+            pattern="[^:*$]*",
+        )
+        next_token = self._get_validated_param(
+            "nextToken", "Minimum length of 1.", lambda x: x is None or 1 <= len(x)
+        )
+
+        if metric_name and not metric_namespace:
+            raise InvalidParameterException(
+                constraint=f"If you include the metricName parameter in your request, "
+                f"you must also include the metricNamespace parameter.",
+                parameter="metricNamespace",
+                value=metric_namespace,
+            )
+        if metric_namespace and not metric_name:
+            raise InvalidParameterException(
+                constraint=f"If you include the metricNamespace parameter in your request, "
+                f"you must also include the metricName parameter.",
+                parameter="metricName",
+                value=metric_name,
+            )
+
+        filters = self.logs_backend.describe_metric_filters(
+            filter_name_prefix, log_group_name, metric_name, metric_namespace
+        )
+        return json.dumps({"metricFilters": filters, "nextToken": next_token})
+
+    def delete_metric_filter(self):
+        filter_name = self._get_validated_param(
+            "filterName",
+            "Minimum length of 1. Maximum length of 512.",
+            lambda x: 1 <= len(x) <= 512,
+            pattern="[^:*]*$",
+        )
+        log_group_name = self._get_validated_param(
+            "logGroupName",
+            "Minimum length of 1. Maximum length of 512.",
+            lambda x: 1 <= len(x) <= 512,
+            pattern="[.-_/#A-Za-z0-9]+$",
+        )
+
+        self.logs_backend.delete_metric_filter(filter_name, log_group_name)
+        return ""
+
     def create_log_group(self):
         log_group_name = self._get_param("logGroupName")
         tags = self._get_param("tags")
