@@ -26,12 +26,13 @@ class MessageAttributesInvalid(RESTError):
 
 
 class QueueDoesNotExist(RESTError):
-    code = 404
+    code = 400
 
     def __init__(self):
-        super(QueueDoesNotExist, self).__init__(
-            "QueueDoesNotExist",
+        super().__init__(
+            "AWS.SimpleQueueService.NonExistentQueue",
             "The specified queue does not exist for this wsdl version.",
+            template="wrapped_single_error",
         )
 
 
@@ -137,3 +138,13 @@ class OverLimit(RESTError):
         super(OverLimit, self).__init__(
             "OverLimit", "{} Actions were found, maximum allowed is 7.".format(count)
         )
+
+
+class InvalidAddress(RESTError):
+    code = 400
+
+    def __init__(self, address):
+        super(InvalidAddress, self).__init__(
+            "InvalidAddress",
+            "The address {} is not valid for this endpoint.".format(address),
+        )
